#!/bin/bash
# Load modules
echo Loading modules...
module purge

module use /usr/local/software/jureca/OtherStages &> /dev/null
module load Stages/2019a &> /dev/null
module use /p/project/cjinm16/schiffer1/software//stages/2019a//modules/
module load atlas/MVAPICH2_PyTorch
echo Modules loaded

# Environment variables
export BRAIN=__BRAIN__
export LABELS=__LABELS__
export SCRATCH_USER=/p/scratch/cjinm16/schiffer1/

# Set annotation directory (assume we are in the experiment folder)
export ATLAS_ANNOTATION_DIR=`pwd`/annotations/
export ATLAS_ANNOTATION_FILE="B${BRAIN}_{slice:04d}_annotations.hdf5"

# Some more variables
INPUT_SPACING=1
OUTPUT_SPACING=16
PREFIX="mask"

# Get path to TIFF images to determine shape
IMAGE_PATTERN=`python -c "from atlas import constants; print(constants.original_path.format(brain=int('${BRAIN}'), slice=1234))"`
echo "Image pattern: ${IMAGE_PATTERN}"

ANNOTATION_PATTERN=`python -c "from atlas import constants; print(constants.annotation_path.format(brain=int('${BRAIN}'), slice=1234))"`
echo "Annotation pattern: ${ANNOTATION_PATTERN}"

# Setup the annotation data
atlas img ann2hdf5 ${ATLAS_ANNOTATION_DIR}/*.json \
                   ${IMAGE_PATTERN} \
                   ${ANNOTATION_PATTERN} \
                   --input-spacing ${INPUT_SPACING} \
                   --output-spacing ${OUTPUT_SPACING} \
                   --prefix ${PREFIX} \
                   --overwrite \
                   --labels ${LABELS} \
                   --chunk-size 64 \
                   --compression gzip

# Setup the experiment data
atlas exp run new `pwd`

# Train network
srun atlas dl train `pwd` --verbose --distribute
